/*  @(#)14  1.5 src/com/tivoli/pd/jazn/demo/PDListObjectsDemo.java, pd.jazn, am611 07/03/15 14:13:28 @(#)  */

/*
 * 15 05 1.15 src/com/tivoli/pd/jazn/demo/PDPermissionDemo.java, pd.permission, am610 9/3/03 15:10:47
 *
 * Licensed Materials - Property of IBM
 * 5748-XX8
 * (c) Copyright International Business Machines Corp. 2003
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * File Name: PDPermissionDemo.java
 */



import java.util.Collections;
import java.util.ArrayList;
import java.util.Set;
import java.net.*;
import java.io.*;
import com.tivoli.pd.jazn.*;
import com.tivoli.pd.jadmin.PDActionGroup;
import com.tivoli.pd.jazn.PDAuthorizationContext;
import com.tivoli.pd.jutil.PDException;
import java.lang.Thread;
/*
import com.tivoli.pd.jadmin.PDAction;
import com.tivoli.pd.jutil.PDAttrs;
import com.tivoli.pd.jutil.PDMessages;
import com.tivoli.pd.jutil.PDStatics;
*/

/**
 * IBM Tivoli Access Manager for e-business PDPermissionDemo class.
 *
 * <p>
 * This class demonstrates the use of the authorization related
 * Access Manager classes.
 * <p>
 * To use the demo you must have a configuration file.  This file is the same
 * as the one specified to the com.tivoli.pd.jcfg.SvrSslCfg
 * configuration program.
 * <p>
 * The demo will create a PDAuthorizationContext using the configuraton data.
 * The PDAuthorizationContext represents the application's configuration
 * and connection to the Access Manager secure domain and the servers therein.
 * The context is used as well to retrieve the list of valid actions in
 * the Access Manager secure domain.
 * <p>
 */

public final class PDListObjectsDemo
{

    private final String PDListObjectsDemo_java_sourceCodeID="$Id: @(#)14  1.5 src/com/tivoli/pd/jazn/demo/PDListObjectsDemo.java, pd.jazn, am611 07/03/15 14:13:28 @(#) $";
    public static final String configFilePrompt = "configuration file";

    String configFile_ = null;

    /**
     * Prompts for input.
     *
     * @param reader  the reader used to retrieve input.
     * @param prompt  string used for prompt when retrieving input.
     * @param def     string default returned when no input is provided.
     *
     * @return        string input.  This is the value specified by the default
     *                string when no input is provided.
     */
    private String prompt(BufferedReader reader,
                          String prompt,
                          String def) throws java.io.IOException
    {
        String result = null;
        System.out.print(prompt);

        if (def != null)
        {
            System.out.print(" [");
            System.out.print(def);
            System.out.print("]");
        }

        System.out.print(":  ");
        result = reader.readLine();
        if (result.length() == 0)
        {
            result = def;
        }
        return result;
    }

    /*
     * Constructs a PDAuthorizationContext based on configuration file input.
     *
     * @param reader  the reader used to retrieve the configuration file
     *                input.  The configuration file specified is used
     *                to construct a PDAuthorizationContext.
     *
     * @return        PDAuthorizationContext based on configuration file
     *                specified.
     */

    private PDAuthorizationContext getPDAuthorizationContext(BufferedReader reader)
    {
        PDAuthorizationContext ctxt=null;
        while (ctxt == null)
        {
            try
            {
                configFile_ = prompt(reader, configFilePrompt, configFile_);
                File cFile = new File(configFile_);
                if (cFile.exists())
                {
                     if (cFile.isFile())
                     {
                          String spec = new String("file:///").concat(configFile_);
                          URL configURL = new URL(spec);
                          ctxt = new PDAuthorizationContext(configURL);
                     }
                     else
                     {
                        System.out.println("Specified configuration file is not a file.");
                     }
                }
                else
                {
                    System.out.println("Specified configuration file does not exist.");
                }
            }
            catch (Exception e)
            {
                e.printStackTrace();
                ctxt = null;
            }
        }
        return ctxt;
    }




    /**
     * Constructs a PDListObjectsDemo object.
     */
    public PDListObjectsDemo()
    {
    }


    void startThread(PDAuthorizationContext ctxt, int num, String res, String recursive)
    {
        int i=0;
        for(i=0; i < num;i++)
        {
           String id = Integer.toString(i);
           Thread listthread = new myThread(ctxt, id, res, recursive);
           listthread.start();
        }
    }


    private class myThread extends Thread
    {
        PDAuthorizationContext ctxt_;
        String res_;
        boolean recursive_;

        public myThread( PDAuthorizationContext ctxt , String threadId, String res, String recursive)
        {
           super(threadId);
           ctxt_ = ctxt;
           res_ = res;
           if(recursive != null && recursive.equals("yes") )
              recursive_ = true;
           else
              recursive_ = false;


        }
        public void run()
        {
             //PDListObjectsDemo demo = new PDListObjectsDemo();

             // while no indication to exit
             try
             {
                 ArrayList list = PDLocalServer.listLocalObjects(ctxt_, res_, recursive_);

                 if ( list != null && !list.isEmpty())
                 {
                       int i =0 ;
                       System.out.println("Thread " + getName() + " :");
                       System.out.println("Object space: " + "res_");
                       System.out.println("Number of objects: "+ list.size());
                       for( i=0; i<list.size();i++)
                       {
                            System.out.println((String)list.get(i));
                       }
                       System.out.println("\n");
                 }
                 else
                 {
                       System.out.println("Thread " + getName());
                       if(list == null)
                            System.out.println(" List is null");
                       if(list.isEmpty())
                            System.out.println(" List is empty");
                       System.out.println("\n");
                 }

             }
             catch (PDException pde)
             {
                   System.out.println("Catch exception here");
                    pde.printStackTrace();
             }

             catch(Exception InterruptedException)
             {
             }

        }
    }

    /**
     * Main program.
     */
    public static void main (String [] argv)
    {
        // construct demo object.
       PDListObjectsDemo demo = new PDListObjectsDemo();


        // construct reader from standard input stream.
        InputStreamReader input = new InputStreamReader(System.in);
        BufferedReader reader = new BufferedReader(input);

        // construct authorization context based on input configuration file.
        PDAuthorizationContext ctxt = demo.getPDAuthorizationContext(reader);

        int numOfThread;
        switch(argv.length)
        {
          case 0:
          {
             demo.startThread(ctxt, 1, "/", "yes");
             break;
          }

          case 1:
          {

            numOfThread = Integer.parseInt(argv[0]);
            demo.startThread(ctxt, numOfThread, "/", "yes");
            break;
          }
          case 2:
          {

            numOfThread = Integer.parseInt(argv[0]);
            demo.startThread(ctxt, numOfThread, argv[1], "yes");
            break;
          }
          case 3:
          {

            numOfThread = Integer.parseInt(argv[0]);
            demo.startThread(ctxt, numOfThread, argv[1], argv[2]);
            break;
          }
          default:
          {
            numOfThread = Integer.parseInt(argv[0]);
            demo.startThread(ctxt, numOfThread, argv[1], argv[2]);
            break;
          }
        }

        // close the context

        if (ctxt != null)
        {
            try
            {
                ctxt.close();
            }
            catch (PDException pde)
            {
                pde.printStackTrace();
            }
        }

    }
}
